api.reports.v1.test_helpers.job package — Argus-Toolbelt 1.0 documentation

# api.reports.v1.test_helpers.job package

## Submodules

## api.reports.v1.test_helpers.job.generate module

`api.reports.v1.test_helpers.job.generate.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job, respond with HTTP 403

`api.reports.v1.test_helpers.job.generate.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job, respond with HTTP 404

`api.reports.v1.test_helpers.job.generate.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job, respond with HTTP 200

`api.reports.v1.test_helpers.job.generate.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job, respond with HTTP 401

## api.reports.v1.test_helpers.job.get module

`api.reports.v1.test_helpers.job.get.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/w+, respond with HTTP 403

`api.reports.v1.test_helpers.job.get.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/w+, respond with HTTP 404

`api.reports.v1.test_helpers.job.get.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/w+, respond with HTTP 200

`api.reports.v1.test_helpers.job.get.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/w+, respond with HTTP 401

## api.reports.v1.test_helpers.job.search module

`api.reports.v1.test_helpers.job.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/search, respond with HTTP 403

`api.reports.v1.test_helpers.job.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/search, respond with HTTP 404

`api.reports.v1.test_helpers.job.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/search, respond with HTTP 200

`api.reports.v1.test_helpers.job.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/job/search, respond with HTTP 401

## Module contents